@@ -2,96 +2,98 @@
 # Author: Moez Ali <moez.ali@queensu.ca>
 # License: MIT
 
-def version():
-    print("1.0.0")
+version_ = "2.1.1"
+nightly_version_ = "2.2"
 
+def version():
+    return version_
+
+def nightly_version():
+    return nightly_version_
+
+def __version__():
+    return version_
 
 def check_metric(actual, prediction, metric, round=4):
     
     """
-    reserved for docstring
+    Function to evaluate classification and regression metrics.
     """
     
     #general dependencies
     import numpy as np
+    from sklearn import metrics
 
     #metric calculation starts here
     
-    if metric == 'accuracy':
+    if metric == 'Accuracy':
         
-        from sklearn import metrics
         result = metrics.accuracy_score(actual,prediction)
         result = result.round(round)
         
-    elif metric == 'recall':
+    elif metric == 'Recall':
         
-        from sklearn import metrics
         result = metrics.recall_score(actual,prediction)
         result = result.round(round)
         
-    elif metric == 'precision':
+    elif metric == 'Precision':
         
-        from sklearn import metrics
         result = metrics.precision_score(actual,prediction)
         result = result.round(round)
         
-    elif metric == 'f1':
+    elif metric == 'F1':
         
-        from sklearn import metrics
         result = metrics.f1_score(actual,prediction)
         result = result.round(round)
         
-    elif metric == 'kappa':
+    elif metric == 'Kappa':
         
-        from sklearn import metrics
         result = metrics.cohen_kappa_score(actual,prediction)
         result = result.round(round)
        
-    elif metric == 'auc':
+    elif metric == 'AUC':
         
-        from sklearn import metrics
         result = metrics.roc_auc_score(actual,prediction)
         result = result.round(round)
         
-    elif metric == 'mae':
+    elif metric == 'MCC':
+        
+        result = metrics.matthews_corrcoef(actual,prediction)
+        result = result.round(round)
+
+    elif metric == 'MAE':
 
-        from sklearn import metrics
         result = metrics.mean_absolute_error(actual,prediction)
         result = result.round(round)
         
-    elif metric == 'mse':
+    elif metric == 'MSE':
 
-        from sklearn import metrics
         result = metrics.mean_squared_error(actual,prediction)
         result = result.round(round)        
         
-    elif metric == 'rmse':
+    elif metric == 'RMSE':
 
-        from sklearn import metrics
         result = metrics.mean_squared_error(actual,prediction)
         result = np.sqrt(result)
         result = result.round(round)     
         
-    elif metric == 'r2':
+    elif metric == 'R2':
 
-        from sklearn import metrics
         result = metrics.r2_score(actual,prediction)
         result = result.round(round)    
         
-    elif metric == 'rmsle':
+    elif metric == 'RMSLE':
 
         result = np.sqrt(np.mean(np.power(np.log(np.array(abs(prediction))+1) - np.log(np.array(abs(actual))+1), 2)))
         result = result.round(round)
 
-    elif metric == 'mape':
+    elif metric == 'MAPE':
 
-        mask = actual != 0
-        result = (np.fabs(actual - prediction)/actual)[mask].mean()
+        mask = actual.iloc[:,0] != 0
+        result = (np.fabs(actual.iloc[:,0] - prediction.iloc[:,0])/actual.iloc[:,0])[mask].mean()
         result = result.round(round)
        
-
-    
-    return result
+    return float(result)
 
 
 def enable_colab():
@@ -117,4 +119,4 @@ def enable_colab():
   
     import IPython
     IPython.get_ipython().events.register('pre_run_cell', configure_plotly_browser_state)
-    print('Colab mode activated.')
\ No newline at end of file
+    print('Colab mode activated.')
